#include<bits/stdc++.h>
using namespace std;

#define EPSILON (1e-7);

bool is_zero(double x) { return abs(x) <= EPSILON; }
bool is_negative(double x) { return x < -EPSILON; }


typedef complex<long long> cll;

template<class T> bool are_equal(const complex<T> &A, const complex<T> &B) {
	return is_zero(real(B) - real(A)) && is_zero(imag(A) - imag(B));
}

template<class T> T cross_product(const complex<T> &A, const complex<T> &B) {
	return real(A) * imag(B) - real(B) * imag(A);
}

template<class T> bool clockwise(const complex<T> &A, const complex<T> &B, const complex<T> &C) {
	return is_negative(cross_product(B - A, C - A));
}
template<class T> bool counterclockwise(const complex<T> &A, const complex<T> &B, const complex<T> &C) {
	return clockwise(C, B, A);
}

template<class T> bool compare_XY(const complex<T> &A, const complex<T> &B) {
	if(!is_zero(real(A) - real(B))) return (is_negative(real(A) - real(B)));
	return is_negative(imag(A) - imag(B));
}
template<class T> bool compare_YX(const complex<T> &A, const complex<T> &B) {
	if(!is_zero(imag(A) - imag(B))) return (is_negative(imag(A) - imag(B)));
	return is_negative(real(A) - real(B));
}

template<class T> int signum(const T &A) { 
	if(is_zero(A)) return 0;
	if(is_negative(A)) return -1;
	return 1;
}

template<class T> T square_size(const complex<T> &A) { return real(A) * real(A) + imag(A) * imag(A); }

template<class T> bool compare_arg(const complex<T> &A, const complex<T> &B) {
	if(are_equal(B, complex<T>(0,0))) return 0;
	if(are_equal(A, complex<T>(0,0))) return 1;
	int sgnA = signum(imag(A));
	int sgnB = signum(imag(B));
	if(sgnA == 0) if(signum(real(A)) < 0) sgnA = 2;
	if(sgnB == 0) if(signum(real(B)) < 0) sgnB = 2;
	if(sgnA != sgnB) return sgnA < sgnB;
	if(counterclockwise(complex<T>(0,0), A, B)) return 1;
	if(clockwise(complex<T>(0,0), A, B)) return 0;
	return square_size(A) < square_size(B);
}

template<class T> vector<complex<T>> convex_hull(vector<complex<T>> V) {
	if(V.size() == 2) if(are_equal(V[0], V[1])) V.pop_back();
	if(V.size() <= 2) return V;
	
	sort(V.begin(), V.end(), compare_YX<T> );
	complex<T> offset = V[0];
	for(unsigned int i = 0; i < V.size(); i++) V[i] -= offset;
	sort(V.begin() + 1, V.end(), compare_arg<T>);
	
	int count = 2;
	vector<int> hull(V.size() + 2);
	for(unsigned int i=0; i < 2; i++) hull[i] = i;
	for(unsigned int i=2; i < V.size(); i++) {
		while(count >= 2&& !counterclockwise(V[hull[count-2]], V[hull[count-1]], V[i])) count--;
		hull[count++] = i;
	}
	vector<complex<T>> res;
	for(int i = 0; i < count; i++) res.push_back(V[hull[i]] + offset);
	if(res.size()==2) if(are_equal(res[0], res[1])) res.pop_back();
	return res;
}

bool operator<(const cll a, const cll b) {
	return compare_XY<long long>(a, b);
}

vector<pair<cll, cll> > TR;
set<cll> s;//([](cll& x, cll& y) { compare_XY<long long>(x, y)});
set<cll> ans;//([](cll& x, cll& y) {compare_XY<long long>(x, y)});
vector<cll> conv;
vector<cll> v;
int N;

int main(){
	cll u, w;
	cin >> N;
	TR.resize(N - 2);
	long long x, y, pos;
	
	for(int i = 0; i<N; i++){
		cin >> x >> y;
		v[i] = {x, y};
	}

	conv = convex_hull(v);
	if(conv.size() == N) cout << 3 << " ";
	else cout << 4 << " ";

	cout << N - conv.size() << " ";
	int d, h, mid;
	int M = conv.size(); 
	for(int i = 0; i<conv.size(); i++){
		s.insert(conv[i]);
	}

	for(int i = 0; i<N; i++){
		if(s.count(v[i])){
			x = i;
			break;
		}
	}

	for(int i = 0; i<conv.size(); i++){
		if(v[x] == conv[i]) pos = i;  
	}

	for(int i = 0; i<conv.size() - 2; i++){
		TR[i] = {conv[(pos + i + 1) % M], conv[(pos + i + 2) % M]};
	}

	for(int i = 0; i<N; i++){
		d = 0;
		h = M - 1;
		if(!s.count(v[i])){
			mid = (d + h) / 2;
			for(int j = 0; j<20; j++){
				u = conv[(mid + i + 1) % M] - conv[pos];
				w = conv[(mid + i + 2) % M] - conv[pos];
				if(cross_product(u, v[i] - conv[pos]) < 0) h = mid - 1;
				else if(cross_product(v[i] - conv[pos], w) < 0)	d = mid + 1;
				else{
					break;
				}
				cout << cross_product(u, w);
				return 0;
				
			}

			ans.insert(conv[(mid + i + 1) % M]);
			ans.insert(conv[(mid + i + 1) % M]);
			ans.insert(conv[pos]);
			ans.insert(v[i]);
		}
	}

	cout << ans.size();	

}
